# $Id$

use strict;
use warnings;

use Test::More tests => 10;
use File::Temp qw(tempdir);
use POSIX qw(strftime);

use_ok('ObsData');
use_ok('ObsData::Repository');

my $o = ObsData->new(
    'testdata/obsdata-conftest', 
    logfile => "testdata/obsdata.log",
    verbose => 0,
);
$o->load();

{
    my $or = ObsData::Repository::dir::archive->new(
        {
            obsdata => $o,
            dir => 'testdata/ohp',
            archivefile => 'ozone12.gz',
            statusfile => 'testdata/test-index.ini',
            dry_run => 1,
        }
    );
    isa_ok($or, "ObsData::Repository::dir::archive");

    # Testing match rules
    ok($or->match_data_type('ozone12'), "is able to find good datatype");
    ok(!$or->match_data_type('foo12'), "is able to find good datatype");

    ok(
        eq_array(
            [ $or->build_dest_filename('ozone12') ],
            [ 'ozone', '12/dest12' ]
        ),
        "Can build dest string"
    );
    ok(
        eq_array(
            [ $or->build_dest_filename('ozone12', 'ozone') ],
            [ 'ozone', '12/dest12' ]
        ),
        "Can build dest string with datatype"
    );
    ok(!defined($or->build_dest_filename('foo12')), "Return undef if no match");
    
    $or->{datatype} = 'oxygene';
    ok(!defined($or->build_dest_filename('ozone12')), "Return undef if no match");
    ok(
        eq_array(
            [ $or->build_dest_filename('oxygene12') ],
            [ 'oxygene', strftime("%Y/dest12/oxygene12", gmtime) ]
        ),
        "Can build dest string with datatype"
    );
}

